@@ -4,7 +4,7 @@ import os
 import subprocess
 import re
 
-from .tools import get_reference_panel_path, get_plink_path
+from .tools import get_reference_panel_path, get_plink_path, run_plink_command
 
 ## TO DO: accept lists of CHR/POS instead of SNP names for these functions
 
@@ -13,13 +13,13 @@ def query_outcome_proxy(df, ld, snps_to_extract, snps_df=[]):
     """
     Extract the best proxies from a dataframe, as well as specific SNPs.
 
-    Given a dataframe `df` (originating from GENO.data) and a dataframe of potential proxies
+    Given a dataframe `df` (originating from Geno.data) and a dataframe of potential proxies
     (output from `find_proxies`), this function extracts the best proxies from `df` as well as
     the SNPs specified in `snps_to_extract`.
     This is suited for querying outcome data.
 
     Args:
-        df (pd.DataFrame): Dataframe of SNP information with the usual GENO columns
+        df (pd.DataFrame): Dataframe of SNP information with the usual Geno columns
                            (SNP, BETA, SE, EAF, EA, NEA). EAF is not necessary.
         ld (pd.DataFrame): Dataframe of proxies (output from `find_proxies`).
         snps_to_extract (list): List of SNPs to extract in addition to the proxies.
@@ -192,11 +192,12 @@ def apply_proxies(df, ld, searchspace=None):
 def find_proxies(
     snp_list,
     searchspace=None,
-    reference_panel="eur",
-    kb=10000,
-    r2=0.6,
-    window_snps=10000,
-    threads=1
+    reference_panel="EUR_37",
+    kb=5000,
+    r2=0.8,
+    window_snps=1000000,
+    threads=1,
+    name=None
 ):
     """
     Given a list of SNPs, return a table of proxies using PLINK 2.0.
@@ -205,11 +206,12 @@ def find_proxies(
         snp_list (list): List of rsids.
         searchspace (list, optional): List of SNPs to include in the search. By default, includes the whole reference panel.
         reference_panel (str, optional): The reference population to get linkage disequilibrium values and find proxies.
-                                         Accepts values: "EUR", "SAS", "AFR", "EAS", "AMR".
-                                         Alternatively, provide a path leading to a specific bed/bim/fam or pgen/pvar/psam reference panel.
+            Acceptable populations are "EUR", "SAS", "AFR", "EAS", "AMR" and available builds are 37 and 38 ("EUR_38" or "AFR_37" etc...)
+            Also accepts or a path to a specific bed/bim/fam or pgen/pvar/psam panel.
+            Default is "EUR_37".
         kb (int, optional): Width of the genomic window to look for proxies. Defaults to 5000.
-        r2 (float, optional): Minimum linkage disequilibrium value with the main SNP for a proxy to be included. Defaults to 0.6.
-        window_snps (int, optional): Compute the LD value for SNPs that are not more than x SNPs apart from the main SNP. Defaults to 5000.
+        r2 (float, optional): Minimum linkage disequilibrium value with the main SNP for a proxy to be included. Defaults to 0.8.
+        window_snps (int, optional): Compute the LD value for SNPs that are not more than x SNPs apart from the main SNP. Defaults to 1000000 (equivalent to infinity).
         threads (int, optional): Number of threads to use. Defaults to 1.
 
     Returns:
@@ -226,13 +228,13 @@ def find_proxies(
         extract_arg = ""
     else:
         print("Searching proxies in the provided searchspace.")
-        with open("tmp_GENAL/searchspace.txt", "w") as file:
+        with open(f"tmp_GENAL/{name}_searchspace.txt", "w") as file:
             for s in searchspace + snp_list:
                 file.write(str(s) + "\n")
-        extract_arg = "--extract tmp_GENAL/searchspace.txt"
+        extract_arg = "--extract tmp_GENAL/{name}_searchspace.txt"
 
     # Save snp_list to a file
-    np.savetxt("tmp_GENAL/snps_to_proxy.txt", snp_list, fmt="%s", delimiter=" ")
+    np.savetxt(f"tmp_GENAL/{name}_snps_to_proxy.txt", snp_list, fmt="%s", delimiter=" ")
 
     # Get reference panel path and type
     ref_path, filetype = get_reference_panel_path(reference_panel)
@@ -255,24 +257,18 @@ def find_proxies(
     command = (
         f"{base_cmd} {extract_arg} "
         f"--r-unphased 'cols=chrom,pos,id,maj,nonmaj,freq' "
-        f"--ld-snp-list tmp_GENAL/snps_to_proxy.txt "
+        f"--ld-snp-list tmp_GENAL/{name}_snps_to_proxy.txt "
         f"--ld-window-kb {kb} "
         f"--ld-window-r2 {r2} "
         f"--ld-window {window_snps} "
         f"--threads {threads} "
-        f"--out tmp_GENAL/proxy.targets"
+        f"--out tmp_GENAL/{name}_proxy.targets"
     )
     
-    try:
-        subprocess.run(command, shell=True, capture_output=True, text=True, check=True)
-    except subprocess.CalledProcessError as e:
-        print(f"Error running PLINK command: {e}")
-        print(f"PLINK stdout: {e.stdout}")
-        print(f"PLINK stderr: {e.stderr}")
-        raise ValueError("PLINK command failed. Check the error messages above for details.")
+    run_plink_command(command)
 
     # Read log file to return amount of SNPs to be proxied present in the ref panel
-    log_path = os.path.join("tmp_GENAL", "proxy.targets.log")
+    log_path = os.path.join("tmp_GENAL", f"{name}_proxy.targets.log")
     log_content = open(log_path).read()
     match = re.search(r'(\d+) variant[s] remaining', log_content)
     if match:
@@ -285,7 +281,7 @@ def find_proxies(
 
     # Read and process the output
     try:
-        ld = pd.read_csv("tmp_GENAL/proxy.targets.vcor", sep="\s+")
+        ld = pd.read_csv(f"tmp_GENAL/{name}_proxy.targets.vcor", sep="\s+")
     except FileNotFoundError:
         print("No proxies found that meet the specified criteria.")
         return None
